# Copyright 2014 Dan Kilman
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from os.path import expanduser
from os import environ

PYSOURCE_HOME_ENV = 'PYSOURCE_HOME'
DEFAULT_PYSOURCE_HOME = '~/.pysource'

pysource_dir = expanduser(environ.get(PYSOURCE_HOME_ENV,
                                      DEFAULT_PYSOURCE_HOME))
